"""empty message

Revision ID: 4e1eb8b4e7f2
Revises: 976c33d240d0
Create Date: 2023-02-23 16:26:11.378536

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "4e1eb8b4e7f2"
down_revision = "976c33d240d0"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint(
        "uniq_cons_site_start_end", "generation", ["site_uuid", "start_utc", "end_utc"]
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint("uniq_cons_site_start_end", "generation", type_="unique")
    # ### end Alembic commands ###
